@@ -9,7 +9,7 @@ from proscan_log_api.utils import get_folders, get_pass_files
 
 @dataclass
 class InterlockEventData:
-    header: Optional[List[str]]
+    header: Optional[dict]
     metadata: Optional[List[str]]
     event: Optional[dict]
     pre_events: Optional[List[dict]]
@@ -29,7 +29,7 @@ class PassClient:
         self.root_dir = root_dir
         self.folders = folders
         self.row_pattern = re.compile(
-            r"(-\s+(?P<id>\d+)\s(?P<timestamp>\d+)\s(?P<value>\w+)\s+(?P<signal_type>\w+)\s+(?P<signal_name>\w+)\s+(?P<datetime>\d{4}-\d{2}-\d{2}\s\d{2}:\d{2}:\d{2}.\d{3}.\d{3})\n)"
+            r"(-\s+(?P<id>\d+)\s(?P<timestamp>\d+)\s(?P<value>\w+)\s+(?P<signalType>\w+)\s+(?P<signalName>\w+)\s+(?P<datetime>\d{4}-\d{2}-\d{2}\s\d{2}:\d{2}:\d{2}.\d{3}.\d{3})\n)"
         )
         self.header_pattern = re.compile(
             r'(?P<log_type>\w+)\s+area=(?P<area>\w+)\s+time=\w+\s(?P<datetime>\d{4}-\d{2}-\d{2}\s\d{2}:\d{2}:\d{2})\s(?P<timezone>\w+)\s\w+\s=\s"(?P<mode>\w+)"\sinScan\s=\s"(?P<inScan>\w+)"'
@@ -89,13 +89,20 @@ class PassClient:
             raise Exception(
                 "Please provide at least one of timestamp, start_date or end_date!"
             )
-        if start_date > end_date:
-            tmp = end_date
-            end_date = start_date
-            start_date = tmp
+
+        if isinstance(start_date, datetime) and isinstance(end_date, datetime):
+            if start_date > end_date:
+                tmp = end_date
+                end_date = start_date
+                start_date = tmp
 
         if timestamp:
-            start_date = end_date = datetime.fromtimestamp(timestamp / 1000000).date()
+            _timestamp_dt = datetime.fromtimestamp(timestamp)
+            if isinstance(_timestamp_dt, datetime):
+                start_date = _timestamp_dt.date()
+                end_date = _timestamp_dt.date()
+            else:
+                raise Exception("Invalid Timestamp Format!")
 
         files = get_pass_files(
             folders=get_folders(folders=self.folders, area=area),
@@ -105,7 +112,6 @@ class PassClient:
         )
 
         for file in files:
-
             for event in self.search_file(
                 file,
                 mask_str=self.create_mask(timestamp=timestamp, signal=signal),
